@@ -2,10 +2,12 @@
 #'
 #' @description Results habitat association
 #'
-#' @param pattern Point pattern or list with reconstructed patterns.
-#' @param raster RasterLayer or list of RasterLayers.
-#' @param significance_level Significance level
-#' @param verbose Print output
+#' @param pattern ppp object with original point pattern data or rd_pat or rd_mar
+#' object with randomized point pattern.
+#' @param raster RasterLayer with original discrete habitat data or rd_ras object with
+#' randomized environmental data.
+#' @param significance_level Double with significance level.
+#' @param verbose Logical if messages should be printed.
 #'
 #' @details
 #' The functions shows significant habitat associations by comparing the number of
@@ -14,12 +16,12 @@
 #' if the observed count in a habitat is above or below a certain threshold of the
 #' randomized count, respectively.
 #'
+#' In case the RasterLayer contains NA cells, this needs to be reflected in the observation
+#' window of the point pattern as well (i.e., no point locations possible in these areas).
+#'
 #' @seealso
-#' \code{\link{randomize_raster}} \cr
-#' \code{\link{translate_raster}} \cr
-#' \code{\link{reconstruct_pattern_homo}} \cr
-#' \code{\link{reconstruct_pattern_hetero}} \cr
-#' \code{\link{reconstruct_pattern_cluster}}
+#' \code{\link{reconstruct_pattern}} \cr
+#' \code{\link{fit_point_process}}
 #'
 #' @return data.frame
 #'
@@ -43,34 +45,39 @@
 results_habitat_association <- function(pattern, raster,
                                         significance_level = 0.05, verbose = TRUE) {
 
-  if (class(pattern) != "rd_pat" && class(raster) != "rd_ras") {
+  if (!inherits(x = pattern, what = "rd_pat") && !inherits(x = raster, what = "rd_ras")) {
 
     stop("Class of 'pattern' or 'raster' must be either 'rd_pat' or 'rd_ras'.",
          call. = FALSE)
+
   }
 
-  if (class(pattern) == "rd_pat" && class(raster) == "rd_ras") {
+  if (inherits(x = pattern, what = "rd_pat") && inherits(x = raster, what = "rd_ras")) {
 
     stop("Please provide only one randomized input.",
          call. = FALSE)
+
   }
 
   if (significance_level < 0.01 || significance_level > 0.1 && verbose) {
+
     warning("Make sure 'signifcance_level' is meaningful (e.g. 'significance_level = 0.05').",
             call. = FALSE)
+
   }
 
   # probs for quantile function from significance level
   threshold <- c(significance_level / 2, 1 - significance_level / 2)
 
   # randomized rasters as input
-  if (class(raster) == "rd_ras") {
+  if (inherits(x = raster, what = "rd_ras")) {
 
     # check if randomized and observed is present
     if (!methods::is(raster$observed, "RasterLayer")) {
 
       stop("The observed raster needs to be included in the input 'raster'.",
            call. = FALSE)
+
     }
 
     # check if extent is identical
@@ -81,6 +88,7 @@ results_habitat_association <- function(pattern, raster,
     if (!same_extent) {
 
       warning("Extent of 'pattern' and 'raster' are not identical.", call. = FALSE)
+
     }
 
     habitats <- sort(table(raster$observed@data@values, useNA = "no")) # get table of habitats
@@ -92,14 +100,16 @@ results_habitat_association <- function(pattern, raster,
 
         warning("The raster has more than 10 classes. Please make sure discrete classes are provided.",
                 call. = FALSE)
+
       }
     }
 
     # print quantiles
     if (verbose) {
 
-      message("> Input: randomized raster | Quantile thresholds: negative < ",
-              threshold[1], " - positive > ", threshold[2])
+      message("> Input: randomized raster\n> Quantile thresholds: negative < ",
+              threshold[1], " || positive > ", threshold[2])
+
     }
 
     # combine observed and randomized to one list again
@@ -113,19 +123,20 @@ results_habitat_association <- function(pattern, raster,
     # extract number of points within each habitat for all list entries
     habitats_count <- lapply(raster, function(current_raster) {
 
-      shar::extract_points(raster = current_raster,
-                           pattern = pattern)
+      extract_points(raster = current_raster, pattern = pattern)
+
     })
   }
 
   # randomized patterns as input
-  else if (class(pattern) == "rd_pat") {
+  else if (inherits(x = pattern, what = "rd_pat")) {
 
     # check if randomized and observed is present
     if (!spatstat.geom::is.ppp(pattern$observed)) {
 
       stop("The observed pattern needs to be included in the input 'pattern'.",
            call. = FALSE)
+
     }
 
     # check if extent is identical
@@ -136,6 +147,14 @@ results_habitat_association <- function(pattern, raster,
     if (!same_extent) {
 
       warning("Extent of 'pattern' and 'raster' are not identical.", call. = FALSE)
+
+    }
+
+    # warning if NA are present
+    if (anyNA(raster@data@values)) {
+
+      warning("NA values present. Please make sure the observation window of the point pattern reflects this.", call. = FALSE)
+
     }
 
     habitats <- sort(table(raster@data@values, useNA = "no")) # get table of habitats
@@ -147,28 +166,30 @@ results_habitat_association <- function(pattern, raster,
 
         warning("The raster has more than 10 classes. Please make sure discrete classes are provided.",
                 call. = FALSE)
+
       }
     }
 
     # print quantiles
     if (verbose) {
-      message("> Input: randomized point pattern | Quantile thresholds: negative < ",
-              threshold[1], " - positive > ", threshold[2])
+
+      message("> Input: randomized pattern\n> Quantile thresholds: negative < ",
+              threshold[1], " || positive > ", threshold[2])
+
     }
 
     # combine observed and randomized to one list again
     pattern <- c(pattern$randomized, list(pattern$observed))
 
-    names(pattern) <- c(paste0("randomized_", seq(from = 1,
-                                                  to = length(pattern) - 1,
+    names(pattern) <- c(paste0("randomized_", seq(from = 1, to = length(pattern) - 1,
                                                   by = 1)),
                              "observed")
 
     # extract number of points within each habitat for all list entries
     habitats_count <- lapply(pattern, function(current_pattern) {
 
-      shar::extract_points(raster = raster,
-                           pattern = current_pattern)
+      extract_points(raster = raster, pattern = current_pattern)
+
     })
   }
 
@@ -191,14 +212,12 @@ results_habitat_association <- function(pattern, raster,
   habitats_count_random <- habitats_count[habitats_count$type != "observed", ]
 
   # get quanitiles of randomized data
-  habitats_count_random_summarised <- do.call(data.frame,
-                                              stats::aggregate(x = data.frame(count = habitats_count_random$count),
-                                                               by = data.frame(habitat = habitats_count_random$habitat),
-                                                               FUN = function(x)
-                                                                 cbind(lo = stats::quantile(x, probs = threshold[[1]]),
-                                                                       hi = stats::quantile(x, probs = threshold[[2]]))))
-
-
+  habitats_count_random_summarised <-
+    do.call(data.frame, stats::aggregate(x = data.frame(count = habitats_count_random$count),
+                                         by = data.frame(habitat = habitats_count_random$habitat),
+                                         FUN = function(x)
+                                           cbind(lo = stats::quantile(x, probs = threshold[[1]]),
+                                                 hi = stats::quantile(x, probs = threshold[[2]]))))
 
   # convert to dataframe
   names(habitats_count_random_summarised) <- c("habitat", "lo", "hi")
@@ -207,16 +226,14 @@ results_habitat_association <- function(pattern, raster,
   habitats_count_obs <- habitats_count[habitats_count$type == "observed", 1:2]
 
   # combine (join) with quantiles of randomized data
-  result <- merge(x = habitats_count_obs,
-                  y = habitats_count_random_summarised,
+  result <- merge(x = habitats_count_obs, y = habitats_count_random_summarised,
                   by = "habitat")
 
   # classify results to positive/negative/n.s.
   result$significance <- ifelse(test = result$count < result$lo,
                                 yes = "negative",
                                 no = ifelse(test = result$count > result$hi,
-                                            yes = "positive",
-                                            no = "n.s."))
+                                            yes = "positive", no = "n.s."))
 
   return(result)
 }
