@@ -1,7 +1,6 @@
 testthat::context("test-classify_habitats")
 
-landscape_classified <- shar::classify_habitats(raster = shar::landscape,
-                                                classes = 5)
+landscape_classified <- classify_habitats(raster = landscape, classes = 5)
 
 ################################################################################
 
